#if defined (HAVE_CONFIG_H)
#  include "config.h"
#endif
/****************************************************************************
** Meta object code from reading C++ file 'octave-qt-link.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "/cygdrive/d/cyg_pub/devel/octave/octave-5.1.0-1.x86_64/src/octave-5.1.0/libgui/src/octave-qt-link.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'octave-qt-link.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_octave__octave_qt_link_t {
    QByteArrayData data[46];
    char stringdata0[754];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_octave__octave_qt_link_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_octave__octave_qt_link_t qt_meta_stringdata_octave__octave_qt_link = {
    {
QT_MOC_LITERAL(0, 0, 22), // "octave::octave_qt_link"
QT_MOC_LITERAL(1, 23, 30), // "copy_image_to_clipboard_signal"
QT_MOC_LITERAL(2, 54, 0), // ""
QT_MOC_LITERAL(3, 55, 4), // "file"
QT_MOC_LITERAL(4, 60, 11), // "remove_file"
QT_MOC_LITERAL(5, 72, 16), // "edit_file_signal"
QT_MOC_LITERAL(6, 89, 23), // "change_directory_signal"
QT_MOC_LITERAL(7, 113, 3), // "dir"
QT_MOC_LITERAL(8, 117, 18), // "file_remove_signal"
QT_MOC_LITERAL(9, 136, 8), // "old_name"
QT_MOC_LITERAL(10, 145, 8), // "new_name"
QT_MOC_LITERAL(11, 154, 19), // "file_renamed_signal"
QT_MOC_LITERAL(12, 174, 8), // "load_new"
QT_MOC_LITERAL(13, 183, 34), // "execute_command_in_terminal_s..."
QT_MOC_LITERAL(14, 218, 7), // "command"
QT_MOC_LITERAL(15, 226, 20), // "set_workspace_signal"
QT_MOC_LITERAL(16, 247, 9), // "top_level"
QT_MOC_LITERAL(17, 257, 5), // "debug"
QT_MOC_LITERAL(18, 263, 16), // "symbol_info_list"
QT_MOC_LITERAL(19, 280, 7), // "syminfo"
QT_MOC_LITERAL(20, 288, 22), // "clear_workspace_signal"
QT_MOC_LITERAL(21, 311, 18), // "set_history_signal"
QT_MOC_LITERAL(22, 330, 4), // "hist"
QT_MOC_LITERAL(23, 335, 21), // "append_history_signal"
QT_MOC_LITERAL(24, 357, 10), // "hist_entry"
QT_MOC_LITERAL(25, 368, 20), // "clear_history_signal"
QT_MOC_LITERAL(26, 389, 21), // "enter_debugger_signal"
QT_MOC_LITERAL(27, 411, 20), // "exit_debugger_signal"
QT_MOC_LITERAL(28, 432, 31), // "update_breakpoint_marker_signal"
QT_MOC_LITERAL(29, 464, 6), // "insert"
QT_MOC_LITERAL(30, 471, 4), // "line"
QT_MOC_LITERAL(31, 476, 4), // "cond"
QT_MOC_LITERAL(32, 481, 30), // "insert_debugger_pointer_signal"
QT_MOC_LITERAL(33, 512, 30), // "delete_debugger_pointer_signal"
QT_MOC_LITERAL(34, 543, 23), // "show_preferences_signal"
QT_MOC_LITERAL(35, 567, 21), // "gui_preference_signal"
QT_MOC_LITERAL(36, 589, 8), // "QString*"
QT_MOC_LITERAL(37, 598, 15), // "show_doc_signal"
QT_MOC_LITERAL(38, 614, 19), // "register_doc_signal"
QT_MOC_LITERAL(39, 634, 21), // "unregister_doc_signal"
QT_MOC_LITERAL(40, 656, 20), // "edit_variable_signal"
QT_MOC_LITERAL(41, 677, 4), // "name"
QT_MOC_LITERAL(42, 682, 12), // "octave_value"
QT_MOC_LITERAL(43, 695, 3), // "val"
QT_MOC_LITERAL(44, 699, 30), // "refresh_variable_editor_signal"
QT_MOC_LITERAL(45, 730, 23) // "confirm_shutdown_signal"

    },
    "octave::octave_qt_link\0"
    "copy_image_to_clipboard_signal\0\0file\0"
    "remove_file\0edit_file_signal\0"
    "change_directory_signal\0dir\0"
    "file_remove_signal\0old_name\0new_name\0"
    "file_renamed_signal\0load_new\0"
    "execute_command_in_terminal_signal\0"
    "command\0set_workspace_signal\0top_level\0"
    "debug\0symbol_info_list\0syminfo\0"
    "clear_workspace_signal\0set_history_signal\0"
    "hist\0append_history_signal\0hist_entry\0"
    "clear_history_signal\0enter_debugger_signal\0"
    "exit_debugger_signal\0"
    "update_breakpoint_marker_signal\0insert\0"
    "line\0cond\0insert_debugger_pointer_signal\0"
    "delete_debugger_pointer_signal\0"
    "show_preferences_signal\0gui_preference_signal\0"
    "QString*\0show_doc_signal\0register_doc_signal\0"
    "unregister_doc_signal\0edit_variable_signal\0"
    "name\0octave_value\0val\0"
    "refresh_variable_editor_signal\0"
    "confirm_shutdown_signal"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_octave__octave_qt_link[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      24,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
      24,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    2,  134,    2, 0x06 /* Public */,
       5,    1,  139,    2, 0x06 /* Public */,
       6,    1,  142,    2, 0x06 /* Public */,
       8,    2,  145,    2, 0x06 /* Public */,
      11,    1,  150,    2, 0x06 /* Public */,
      13,    1,  153,    2, 0x06 /* Public */,
      15,    3,  156,    2, 0x06 /* Public */,
      20,    0,  163,    2, 0x06 /* Public */,
      21,    1,  164,    2, 0x06 /* Public */,
      23,    1,  167,    2, 0x06 /* Public */,
      25,    0,  170,    2, 0x06 /* Public */,
      26,    0,  171,    2, 0x06 /* Public */,
      27,    0,  172,    2, 0x06 /* Public */,
      28,    4,  173,    2, 0x06 /* Public */,
      32,    2,  182,    2, 0x06 /* Public */,
      33,    2,  187,    2, 0x06 /* Public */,
      34,    0,  192,    2, 0x06 /* Public */,
      35,    3,  193,    2, 0x06 /* Public */,
      37,    1,  200,    2, 0x06 /* Public */,
      38,    1,  203,    2, 0x06 /* Public */,
      39,    1,  206,    2, 0x06 /* Public */,
      40,    2,  209,    2, 0x06 /* Public */,
      44,    0,  214,    2, 0x06 /* Public */,
      45,    0,  215,    2, 0x06 /* Public */,

 // signals: parameters
    QMetaType::Void, QMetaType::QString, QMetaType::Bool,    3,    4,
    QMetaType::Void, QMetaType::QString,    3,
    QMetaType::Void, QMetaType::QString,    7,
    QMetaType::Void, QMetaType::QString, QMetaType::QString,    9,   10,
    QMetaType::Void, QMetaType::Bool,   12,
    QMetaType::Void, QMetaType::QString,   14,
    QMetaType::Void, QMetaType::Bool, QMetaType::Bool, 0x80000000 | 18,   16,   17,   19,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QStringList,   22,
    QMetaType::Void, QMetaType::QString,   24,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool, QMetaType::QString, QMetaType::Int, QMetaType::QString,   29,    3,   30,   31,
    QMetaType::Void, QMetaType::QString, QMetaType::Int,    2,    2,
    QMetaType::Void, QMetaType::QString, QMetaType::Int,    2,    2,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString, QMetaType::QString, 0x80000000 | 36,    2,    2,    2,
    QMetaType::Void, QMetaType::QString,    3,
    QMetaType::Void, QMetaType::QString,    3,
    QMetaType::Void, QMetaType::QString,    3,
    QMetaType::Void, QMetaType::QString, 0x80000000 | 42,   41,   43,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void octave::octave_qt_link::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        octave_qt_link *_t = static_cast<octave_qt_link *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->copy_image_to_clipboard_signal((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2]))); break;
        case 1: _t->edit_file_signal((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 2: _t->change_directory_signal((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 3: _t->file_remove_signal((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 4: _t->file_renamed_signal((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 5: _t->execute_command_in_terminal_signal((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 6: _t->set_workspace_signal((*reinterpret_cast< bool(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2])),(*reinterpret_cast< const symbol_info_list(*)>(_a[3]))); break;
        case 7: _t->clear_workspace_signal(); break;
        case 8: _t->set_history_signal((*reinterpret_cast< const QStringList(*)>(_a[1]))); break;
        case 9: _t->append_history_signal((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 10: _t->clear_history_signal(); break;
        case 11: _t->enter_debugger_signal(); break;
        case 12: _t->exit_debugger_signal(); break;
        case 13: _t->update_breakpoint_marker_signal((*reinterpret_cast< bool(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3])),(*reinterpret_cast< const QString(*)>(_a[4]))); break;
        case 14: _t->insert_debugger_pointer_signal((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 15: _t->delete_debugger_pointer_signal((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 16: _t->show_preferences_signal(); break;
        case 17: _t->gui_preference_signal((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< QString*(*)>(_a[3]))); break;
        case 18: _t->show_doc_signal((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 19: _t->register_doc_signal((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 20: _t->unregister_doc_signal((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 21: _t->edit_variable_signal((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const octave_value(*)>(_a[2]))); break;
        case 22: _t->refresh_variable_editor_signal(); break;
        case 23: _t->confirm_shutdown_signal(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (octave_qt_link::*_t)(const QString & , bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&octave_qt_link::copy_image_to_clipboard_signal)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (octave_qt_link::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&octave_qt_link::edit_file_signal)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (octave_qt_link::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&octave_qt_link::change_directory_signal)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (octave_qt_link::*_t)(const QString & , const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&octave_qt_link::file_remove_signal)) {
                *result = 3;
                return;
            }
        }
        {
            typedef void (octave_qt_link::*_t)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&octave_qt_link::file_renamed_signal)) {
                *result = 4;
                return;
            }
        }
        {
            typedef void (octave_qt_link::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&octave_qt_link::execute_command_in_terminal_signal)) {
                *result = 5;
                return;
            }
        }
        {
            typedef void (octave_qt_link::*_t)(bool , bool , const symbol_info_list & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&octave_qt_link::set_workspace_signal)) {
                *result = 6;
                return;
            }
        }
        {
            typedef void (octave_qt_link::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&octave_qt_link::clear_workspace_signal)) {
                *result = 7;
                return;
            }
        }
        {
            typedef void (octave_qt_link::*_t)(const QStringList & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&octave_qt_link::set_history_signal)) {
                *result = 8;
                return;
            }
        }
        {
            typedef void (octave_qt_link::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&octave_qt_link::append_history_signal)) {
                *result = 9;
                return;
            }
        }
        {
            typedef void (octave_qt_link::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&octave_qt_link::clear_history_signal)) {
                *result = 10;
                return;
            }
        }
        {
            typedef void (octave_qt_link::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&octave_qt_link::enter_debugger_signal)) {
                *result = 11;
                return;
            }
        }
        {
            typedef void (octave_qt_link::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&octave_qt_link::exit_debugger_signal)) {
                *result = 12;
                return;
            }
        }
        {
            typedef void (octave_qt_link::*_t)(bool , const QString & , int , const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&octave_qt_link::update_breakpoint_marker_signal)) {
                *result = 13;
                return;
            }
        }
        {
            typedef void (octave_qt_link::*_t)(const QString & , int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&octave_qt_link::insert_debugger_pointer_signal)) {
                *result = 14;
                return;
            }
        }
        {
            typedef void (octave_qt_link::*_t)(const QString & , int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&octave_qt_link::delete_debugger_pointer_signal)) {
                *result = 15;
                return;
            }
        }
        {
            typedef void (octave_qt_link::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&octave_qt_link::show_preferences_signal)) {
                *result = 16;
                return;
            }
        }
        {
            typedef void (octave_qt_link::*_t)(const QString & , const QString & , QString * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&octave_qt_link::gui_preference_signal)) {
                *result = 17;
                return;
            }
        }
        {
            typedef void (octave_qt_link::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&octave_qt_link::show_doc_signal)) {
                *result = 18;
                return;
            }
        }
        {
            typedef void (octave_qt_link::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&octave_qt_link::register_doc_signal)) {
                *result = 19;
                return;
            }
        }
        {
            typedef void (octave_qt_link::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&octave_qt_link::unregister_doc_signal)) {
                *result = 20;
                return;
            }
        }
        {
            typedef void (octave_qt_link::*_t)(const QString & , const octave_value & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&octave_qt_link::edit_variable_signal)) {
                *result = 21;
                return;
            }
        }
        {
            typedef void (octave_qt_link::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&octave_qt_link::refresh_variable_editor_signal)) {
                *result = 22;
                return;
            }
        }
        {
            typedef void (octave_qt_link::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&octave_qt_link::confirm_shutdown_signal)) {
                *result = 23;
                return;
            }
        }
    }
}

const QMetaObject octave::octave_qt_link::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_octave__octave_qt_link.data,
      qt_meta_data_octave__octave_qt_link,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *octave::octave_qt_link::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *octave::octave_qt_link::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_octave__octave_qt_link.stringdata0))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "octave_link"))
        return static_cast< octave_link*>(this);
    return QObject::qt_metacast(_clname);
}

int octave::octave_qt_link::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 24)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 24;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 24)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 24;
    }
    return _id;
}

// SIGNAL 0
void octave::octave_qt_link::copy_image_to_clipboard_signal(const QString & _t1, bool _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void octave::octave_qt_link::edit_file_signal(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void octave::octave_qt_link::change_directory_signal(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void octave::octave_qt_link::file_remove_signal(const QString & _t1, const QString & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void octave::octave_qt_link::file_renamed_signal(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}

// SIGNAL 5
void octave::octave_qt_link::execute_command_in_terminal_signal(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 5, _a);
}

// SIGNAL 6
void octave::octave_qt_link::set_workspace_signal(bool _t1, bool _t2, const symbol_info_list & _t3)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)), const_cast<void*>(reinterpret_cast<const void*>(&_t3)) };
    QMetaObject::activate(this, &staticMetaObject, 6, _a);
}

// SIGNAL 7
void octave::octave_qt_link::clear_workspace_signal()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void octave::octave_qt_link::set_history_signal(const QStringList & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 8, _a);
}

// SIGNAL 9
void octave::octave_qt_link::append_history_signal(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 9, _a);
}

// SIGNAL 10
void octave::octave_qt_link::clear_history_signal()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void octave::octave_qt_link::enter_debugger_signal()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void octave::octave_qt_link::exit_debugger_signal()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}

// SIGNAL 13
void octave::octave_qt_link::update_breakpoint_marker_signal(bool _t1, const QString & _t2, int _t3, const QString & _t4)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)), const_cast<void*>(reinterpret_cast<const void*>(&_t3)), const_cast<void*>(reinterpret_cast<const void*>(&_t4)) };
    QMetaObject::activate(this, &staticMetaObject, 13, _a);
}

// SIGNAL 14
void octave::octave_qt_link::insert_debugger_pointer_signal(const QString & _t1, int _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 14, _a);
}

// SIGNAL 15
void octave::octave_qt_link::delete_debugger_pointer_signal(const QString & _t1, int _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 15, _a);
}

// SIGNAL 16
void octave::octave_qt_link::show_preferences_signal()
{
    QMetaObject::activate(this, &staticMetaObject, 16, nullptr);
}

// SIGNAL 17
void octave::octave_qt_link::gui_preference_signal(const QString & _t1, const QString & _t2, QString * _t3)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)), const_cast<void*>(reinterpret_cast<const void*>(&_t3)) };
    QMetaObject::activate(this, &staticMetaObject, 17, _a);
}

// SIGNAL 18
void octave::octave_qt_link::show_doc_signal(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 18, _a);
}

// SIGNAL 19
void octave::octave_qt_link::register_doc_signal(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 19, _a);
}

// SIGNAL 20
void octave::octave_qt_link::unregister_doc_signal(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 20, _a);
}

// SIGNAL 21
void octave::octave_qt_link::edit_variable_signal(const QString & _t1, const octave_value & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 21, _a);
}

// SIGNAL 22
void octave::octave_qt_link::refresh_variable_editor_signal()
{
    QMetaObject::activate(this, &staticMetaObject, 22, nullptr);
}

// SIGNAL 23
void octave::octave_qt_link::confirm_shutdown_signal()
{
    QMetaObject::activate(this, &staticMetaObject, 23, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
